% Les formats de documents ouverts
% François Pelletier
% 25 novembre 2017

# Les différents formats de documents ouverts

## OpenDocument

- Format ouvert de données pour la bureautique.
- Basé sur la notation XML, assez proche du HTML
- Plusieurs types de documents:
    - Traitement de texte
    - Tableur
    - Présentation
    - Diagramme
    - Base de données
- Norme publiée par OASIS

---

### OpenDocument: Avantages

- Interopérabilité: OpenOffice.org, LibreOffice, KOffice, Google Documents, IBM Notes
- Microsoft Office ne gère pas bien le format OpenDocument afin de lui donner une impression de mauvaise qualité.
- Abri contre la péremption des données
- Permet un formatage riche du contenu
- Permet l'automatisation de la production de documents

### OpenDocument: Inconvénients

- Les fichiers sont lourds
- Il peut être difficile d'éditer le code XML directement sans corrompre le document
- L'utilisation des logiciels d'édition nécessite une période d'apprentissage et beaucoup de pratique.
- Intégration limitée de contenu scientifique tel que des équations ou des diagrammes

---

### OpenDocument: Éditeurs libres

- OpenOffice.org
- LibreOffice
- NeoOffice
- KOffice
- AbiWord

---

### OpenDocument: Références

- [OASIS Open Document Format for Office Applications (OpenDocument) TC](https://www.oasis-open.org/committees/tc_home.php?wg_abbrev=office)
- [Document Freedom Day](http://www.documentfreedom.org/index.php)

## \LaTeX

- \LaTeX\ est un système de préparation de document. 
- Constitue un ensemble de macros développées par Leslie Lamport servant à faciliter l'utilisation de \TeX, le langage créé par Donald Knuth.
- Conçu pour la production de documents techniques et scientifiques.

---

### \LaTeX\ : Avantages

- Standard reconnu par la plupart des publications scientifiques.
- Permet de ne pas avoir à se soucier de l'apparence finale du document et de se concentrer sur le contenu.
- Permet de structurer efficacement de très grands documents
    - Table des matières
    - Création d'index et de bibliographie
    - Numérotation automatique des chapitres, sections et sous-sections
- Permet d'inclure des formules mathématiques et scientifiques très complexes
- Permet de générer des figures et des graphiques très complexes
- Bien intégré avec la plupart des langages de programmation pour la génération automatique de contenu et de documentation.

---

### \LaTeX\ : Inconvénients

- Apprentissage difficile.
- C'est un langage de programmation compilé.
- Déboguer un document qui ne compile pas peut être ardu.
- Le document produit est à la base dans un format imprimable, ce qui peut être contraignant (surtout sur la largeur du document).

---

### Distributions de \LaTeX

- [MikTeX](https://miktex.org/), la distribution recommandée pour Windows. Aussi disponible sur macOS via Homebrew.
- [TeX Live](https://www.tug.org/texlive/), la distribution la plus courante et celle par défaut sur les distributions majeures de GNU/Linux
- [MacTeX](http://www.tug.org/mactex/), distribution TeX Live adaptée pour macOS

---

### \LaTeX\ : Éditeurs libres

- [AucTeX](https://www.gnu.org/software/auctex/), extension de GNU Emacs pour \TeX, Multi-plateforme
- [TeXMaker](http://www.xm1math.net/texmaker/), interface graphique Multi-plateforme
- [LyX](https://www.lyx.org/), Éditeur de type WYSIWYM utilisant \LaTeX\ en arrière plan. Multi-plateforme
- [LaTeXila](https://wiki.gnome.org/Apps/LaTeXila), interface graphique pour GNOME, GNU/Linux seulement
- [TeXnicCenter](http://www.texniccenter.org/), interface graphique avancée pour Windows seulement.

---

### \LaTeX\ : Références

- [The \LaTeX\ Project](http://www.latex-project.org/)
- [\TeX Users Group web site](http://tug.org/)
- [\LaTeX\ Wikibook](https://en.wikibooks.org/wiki/LaTeX)

## Markdown

- Markdown est un langage de balisage léger
- Inspiré du courriel en mode texte
- Il en existe plusieurs variantes, dont le GitHub Flavored Markdown, le Pandoc Markdown et le R Markdown
- Très populaire pour produire de la documentation
- Presque toujours converti vers un format HTML

### Markdown:nÉditeurs libres

- [Remarkable](https://remarkableapp.github.io/), Windows et GNU/Linux
- [Visual Studio Code](https://github.com/Microsoft/vscode), Multi-plateforme
- [Stackedit](https://stackedit.io/), Multi-plateforme, application web

### Markdown: Références

- [Site officiel](http://daringfireball.net/projects/markdown/)
- [Un guide pour bien commencer avec markdown](https://blog.wax-o.com/2014/04/tutoriel-un-guide-pour-bien-commencer-avec-markdown/)

## DocBook

- DocBook est un schéma XML très large qui permet de définir sémantiquement le contenu d'un livre ou d'un article.
- Il ne définit pas comment l'affichage se fait. On utilisera alors un fichier XSLT qui permet de transformer le XML dans un autre format, souvent le HTML.

### DocBook: Références

- [What is DocBook?](http://docbook.org/whatis)

# Pandoc



## Exploiter Pandoc Markdown

## Produire des présentations facilement

Un exemple: cette présentation a été écrite avec le langage Markdown et exportée en PDF et en HTML avec Pandoc.

```bash
pandoc -t slidy -s presentation.md -o presentation.html
```

```bash
pandoc -t beamer -s presentation.md -o presentation.pdf
```

## Publier sur un wiki ou un site web

# Tesseract

# pdftk

## Concaténer des documents

## Extraire une section d'un document

# imagemagick

## Appliquer un filigrane

## Ajouter un logo